nagios_host 'ama-guides.ama-assn.org' do
	options 'use' => 'noping-host-https',
		'alias' => 'AMA Home',
		'address' => 'ama-guides.ama-assn.org',
		'contact_groups' => 'cs_escalation,ama',
		'notes' => 'AMA Live Site',
		'notes_url' => 'https://kglpubfactory.atlassian.net/wiki/spaces/AMA/pages/3345416204/Server+Setup+-+AMA+American+Medical+Association'
end
nagios_host 'admin-ama-guides.ama-assn.org' do
	options 'use' => 'noping-host-https',
		'alias' => 'AMA Admin',
		'address' => 'admin-ama-guides.ama-assn.org',
		'contact_groups' => 'cs_escalation,ama',
		'notes' => 'AMA Production Management Portal',
		'notes_url' => 'https://kglpubfactory.atlassian.net/wiki/spaces/AMA/pages/3345416204/Server+Setup+-+AMA+American+Medical+Association'
end
nagios_host 'ams-ama-guides.ama-assn.org' do
	options 'use' => 'noping-host-https',
		'alias' => 'AMA AMS',
		'address' => 'ams-ama-guides.ama-assn.org',
		'contact_groups' => 'cs_escalation,ama',
		'notes' => 'AMA Production AMS',
		'notes_url' => 'https://kglpubfactory.atlassian.net/wiki/spaces/AMA/pages/3345416204/Server+Setup+-+AMA+American+Medical+Association'
end
#------------------------------------------------------------------------------------
# HOMEPAGE
# checks the homepage of the live AMA site and checks for the string 'American Medical Association'.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'ama-guides.ama-assn.org-Live Homepage' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'ama-guides.ama-assn.org',
		'display_name' => 'Live Homepage',
		'check_command' => 'https_content_check_basic_auth!ama:ama2023!/!"American Medical Association"!10!20!',
		'contact_groups' => 'cs_escalation,ama',
		'notes' => 'AMA Live Site',
		'notes_url' => 'https://ama-guides.ama-assn.org'
end
#------------------------------------------------------------------------------------
# SEARCH
# Checks the browse of the live AMA site and checks for the string 'Browse'.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'ama-guides.ama-assn.org-Live Browse' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'ama-guides.ama-assn.org',
		'display_name' => 'Live Browse',
		'check_command' => 'https_content_check_basic_auth!ama:ama2023!/browse!Browse!10!20!',
		'contact_groups' => 'cs_escalation,ama',
		'notes' => 'AMA Live Site',
		'notes_url' => 'https://ama-guides.ama-assn.org/browse'
end
#------------------------------------------------------------------------------------
# CONTENT VIEW
# checks the content view of the live AMA site and checks for the string 'Medical'.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'ama-guides.ama-assn.org-Live content view' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'ama-guides.ama-assn.org',
		'display_name' => 'Live content view',
		'check_command' => 'https_content_check_basic_auth!ama:ama2023!/view/journals/ama-guides-newsl/29/1/article-p4.xml!Compensation!10!20!',
		'contact_groups' => 'cs_escalation,ama',
		'notes' => 'AMA Live Site',
		'notes_url' => 'https://journals.ama.org/view/journals/2054/2054-overview.xml'
end
#------------------------------------------------------------------------------------
# LOADER
# Checks a loader login page and looks for the string 'AMA PROD' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'ama-guides.ama-assn.org-Production Loader' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'admin-ama-guides.ama-assn.org',
		'display_name' => 'Production Loader',
		'check_command' => 'check_loader_auth!admin-ama-guides.ama-assn.org!/login!ama:ama2023!"AMA Production"!20!10',
		'contact_groups' => 'admins_email_only,ama',
		'notes' => 'AMA Live Loader',
		'notes_url' => 'https://admin-ama-guides.ama-assn.org/login'
end
#------------------------------------------------------------------------------------
# STAGING
# Checks the staging site homepage and looks for the string 'Medical' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'ama-guides.ama-assn.org-Staging Homepage' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'ama-guides.ama-assn.org',
		'display_name' => 'Staging Homepage',
		'check_command' => 'check_staging_auth!staging-ama-guides.ama-assn.org!ama:ama2023!"Medical"!20!10',
		'contact_groups' => 'admins_email_only,ama',
		'notes' => 'AMA Staging Site',
		'notes_url' => 'staging-ama-guides.ama-assn.org'
end
#------------------------------------------------------------------------------------
# AMX
# Checks the production amx homepage and looks for the string 'AMS' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'ama-guides.ama-assn.org-Production AMX' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'ams-ama-guides.ama-assn.org',
		'display_name' => 'Production AMX',
		'check_command' => 'check_loader_auth!ams-ama-guides.ama-assn.org!/login!ama:ama2023!AMS!20!10',
		'contact_groups' => 'admins_email_only,ama',
		'notes' => 'AMA AMX',
		'notes_url' => 'https://ams-ama-guides.ama-assn.org/login'
end
#------------------------------------------------------------------------------------
# FAIL OPEN
# Checks the production homepage and makes sure we're not in fail open by checking
# that the string "Provisional Account" is NOT in the page.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'ama-guides.ama-assn.org-Live Site Fail Open' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'ama-guides.ama-assn.org',
		'display_name' => 'Live Site Fail Open',
		'check_command' => 'http_negate_content_check_basic_auth!ama-guides.ama-assn.org!ama:ama2023!"provisional account"',
		'contact_groups' => 'admins_email_only,ama',
		'notes' => 'AMA Live Site Failopen',
		'notes_url' => 'https://ama-guides.ama-assn.org/'
end
#------------------------------------------------------------------------------------
# HOMEPAGE (NODE 1)
# checks the homepage of the live ama site on the first web node and checks for the string 'AMS'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'ama-guides.ama-assn.org-Live Homepage: ama-web-1' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'ama-guides.ama-assn.org',
		'display_name' => 'Live Homepage: ama-web-1',
		'check_command' => 'https_content_check_basic_auth_single_node!ama:ama2023!/!"AMS"!10!20!ama-web-live1!ama-web-1.irl.pubfactory.net!',
		'contact_groups' => 'admins_email_only,ama',
		'notes' => 'AMA Live Site: ama-web-1',
		'notes_url' => 'https://ama-guides.ama-assn.org'
end
#------------------------------------------------------------------------------------
# HOMEPAGE (NODE 2)
# checks the homepage of the live ama site on the first web node and checks for the string 'AMS'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'ama-guides.ama-assn.org-Live Homepage: ama-web-2' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'ama-guides.ama-assn.org',
		'display_name' => 'Live Homepage: ama-web-2',
		'check_command' => 'https_content_check_basic_auth_single_node!ama:ama2023!/!"AMS"!10!20!ama-web-live2!ama-web-2.irl.pubfactory.net!',
		'contact_groups' => 'admins_email_only,ama',
		'notes' => 'AMA Live Site: ama-web-2',
		'notes_url' => 'https://ama-guides.ama-assn.org'
end
